==> koffice2_1.9.95.orig.tar.gz: koffice-1.9.95/libs/flake/commands/KoConnectionShapeTypeCommand.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KoConnectionShapeTypeCommand.h"
#include <klocale.h>

KoConnectionShapeTypeCommand::KoConnectionShapeTypeCommand( 
        KoConnectionShape * connection, KoConnectionShape::Type type, QUndoCommand *parent )
    : QUndoCommand( parent )
    , m_connection(connection)
    , m_newType(type)
{
    Q_ASSERT(m_connection);

    setText( i18n("Change Connection") );

    m_oldType = m_connection->connectionType();
}

void KoConnectionShapeTypeCommand::redo()
{
    QUndoCommand::redo();

    m_connection->update();

    if( m_oldType != m_newType )
        m_connection->setConnectionType( m_newType );

    m_connection->update();
}

void KoConnectionShapeTypeCommand::undo()
{
    QUndoCommand::undo();

    m_connection->update();

    if( m_oldType != m_newType )
        m_connection->setConnectionType( m_oldType );

    m_connection->update();
}

==> koffice_2.2.0-7.tar.gz: koffice-2.2.0/libs/flake/commands/KoConnectionShapeTypeCommand.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KoConnectionShapeTypeCommand.h"
#include <klocale.h>

KoConnectionShapeTypeCommand::KoConnectionShapeTypeCommand(
    KoConnectionShape * connection, KoConnectionShape::Type type, QUndoCommand *parent)
        : QUndoCommand(parent)
        , m_connection(connection)
        , m_newType(type)
{
    Q_ASSERT(m_connection);

    setText(i18n("Change Connection"));

    m_oldType = m_connection->type();
}

void KoConnectionShapeTypeCommand::redo()
{
    QUndoCommand::redo();

    m_connection->update();

    if (m_oldType != m_newType)
        m_connection->setType(m_newType);

    m_connection->update();
}

void KoConnectionShapeTypeCommand::undo()
{
    QUndoCommand::undo();

    m_connection->update();

    if (m_oldType != m_newType)
        m_connection->setType(m_oldType);

    m_connection->update();
}
